#!/usr/bin/env python

#
# Wiretap SDK tool for getting the root node of a Wiretap server.
#

from __future__ import print_function

import getopt
import sys

from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "[-h <hostname>]")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:")
    except getopt.GetoptError:
        printUsage()
        return 2

    # Declare variable for hostName.
    # The default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""

    # Parse command line and set value for hostName.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        if opt == '-n':
            nodeId = arg

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        return 2

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate a node and set it to the root node obtained from the server
        #
        node = WireTapNodeHandle(server, nodeId)
        parent = WireTapNodeHandle()
        print(dir(node))
        if not node.getParentNode(parent):
            raise Exception("Unable to retrieve parent node: %s" % server.lastError())

        print(node.getNodeId().id())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        parent = None
        server = None

    return 0

if __name__ == '__main__':
    exitCode = main()
    sys.exit(exitCode)
