#!/usr/bin/env python

#
# Wiretap SDK tool for setting the metadata associated with a node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
    WireTapMetaData
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "[-h <hostname>]\n"
          "[-s <metadata stream name (default = 'XML')>]\n"
          "[-f <metadata filename>]\n")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:s:f:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""
    fileHandle = None
    streamName = WireTapMetaData.STREAM_XML()

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg
        elif opt == '-s':
            streamName = arg
        elif opt == '-f':
            try:
                fileHandle = open(arg, 'r')
            except IOError, e:
                raise Exception("Cannot read meta data file '%s': %s" % (arg, e))

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    if not fileHandle:
        print("Metadata file not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Create a node.
        #
        node = WireTapNodeHandle(server, nodeId)

        # Set metadata
        #
        if not node.setMetaData(streamName, fileHandle.read()):
            raise Exception("Unable to set meta data: %s "% node.lastError())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None

if __name__ == '__main__':
    main()
